@@ -12,9 +12,9 @@ import os
 import pathlib
 import re
 import shutil
+import socket
 import ssl
 import sys
-import socket
 import tempfile
 import threading
 import time
@@ -24,9 +24,9 @@ import zipfile
 from typing import Iterator, Optional, Union
 
 import requests
+from deprecation import deprecated
 from logzero import setup_logger
 from PIL import Image
-from retry import retry
 
 from . import bplist
 from ._crash import CrashManager
@@ -671,18 +671,18 @@ class BaseDevice():
         """
         return pid killed
         """
-        instruments = self.connect_instruments()
-        if isinstance(pid_or_name, int):
-            instruments.app_kill(pid_or_name)
-            return pid_or_name
-        elif isinstance(pid_or_name, str):
-            bundle_id = pid_or_name
-            app_infos = list(self.installation.iter_installed(app_type=None))
-            ps = instruments.app_process_list(app_infos)
-            for p in ps:
-                if p['bundle_id'] == bundle_id:
-                    instruments.app_kill(p['pid'])
-                    return p['pid']
+        with self.connect_instruments() as ts:
+            if isinstance(pid_or_name, int):
+                ts.app_kill(pid_or_name)
+                return pid_or_name
+            elif isinstance(pid_or_name, str):
+                bundle_id = pid_or_name
+                app_infos = list(self.installation.iter_installed(app_type=None))
+                ps = ts.app_process_list(app_infos)
+                for p in ps:
+                    if p['bundle_id'] == bundle_id:
+                        ts.app_kill(p['pid'])
+                        return p['pid']
         return None
 
     def app_kill(self, *args, **kwargs) -> int:
@@ -698,10 +698,8 @@ class BaseDevice():
         
         return pid
         """
-        instruments = self.connect_instruments()
-        return instruments.app_launch(bundle_id,
-                                           args=args,
-                                           kill_running=kill_running)
+        with self.connect_instruments() as ts:
+            return ts.app_launch(bundle_id, args=args, kill_running=kill_running)
 
     def app_install(self, file_or_url: Union[str, typing.IO]) -> str:
         """
@@ -772,7 +770,7 @@ class BaseDevice():
         print("DONE.")
 
         print("Installing {!r} {!r}".format(bundle_id, short_version))
-        self.installation.install(bundle_id, target_path)
+        return self.installation.install(bundle_id, target_path)
 
     def app_uninstall(self, bundle_id: str) -> bool:
         """
@@ -795,12 +793,13 @@ class BaseDevice():
                 LockdownService.InstrumentsRemoteServerSecure)
         else:
             conn = self.start_service(LockdownService.InstrumentsRemoteServer)
+
         return ServiceInstruments(conn)
-
-    @property
-    def instruments(self) -> ServiceInstruments:
+    
+    @deprecated(details="use connect_instruments instead")
+    def instruments_context(self) -> typing.Generator[ServiceInstruments, None, None]:
         return self.connect_instruments()
-
+        
     def _launch_app_runner(self,
                     bundle_id: str,
                     session_identifier: uuid.UUID,
